[![Build Status](https://travis-ci.org/autodiff-cs207/AutoDiff.svg?branch=master)](https://travis-ci.org/autodiff-cs207/AutoDiff.svg?branch=master)
     
 
[![Coverage Status](https://coveralls.io/repos/github/autodiff-cs207/AutoDiff/badge.svg?branch=master)](https://coveralls.io/github/autodiff-cs207/AutoDiff?branch=master)
 
#  cs207-FinalProject
## Group Information
* Group name: autodiff-cs207
* Members:
     * Claire Stolz
     * Abhimanyu Talwar
     * Feng Qian (Nick)
     * Christy Cheng
 
### Install

After cloning, please run:
```
python setup.py install
```
